ToFieldsRaw

Trait ToFieldsRaw 

pub trait ToFieldsRaw: ToFields {
    // Required method
    fn to_fields_raw(&self) -> Result<Vec<Self::Field>, Error>;
}
Unary operator for converting to a list of base fields.

Required Methods

fn to_fields_raw(&self) -> Result<Vec<Self::Field>, Error>

Returns the object as a list of base field elements using the raw bits.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors