pub struct TestRng { /* private fields */ }Expand description
A fast RNG used solely for testing and benchmarking, not for any real world purposes.
Implementations
Sourceimpl TestRng
impl TestRng
pub fn fixed(seed: u64) -> TestRng
pub fn from_seed(seed: u64) -> TestRng
Sourcepub fn next_string(&mut self, max_bytes: u32, is_fixed_size: bool) -> String
pub fn next_string(&mut self, max_bytes: u32, is_fixed_size: bool) -> String
Returns a randomly-sampled String, given the maximum size in bytes and an RNG.
Some of the snarkVM internal tests involve the random generation of strings, which are parsed and tested against the original ones. However, since the string parser rejects certain characters, if those characters are randomly generated, the tests fail.
To prevent these failures, as we randomly generate the characters, we ensure that they are not among the ones rejected by the parser; if they are, we adjust them to be allowed characters.
Note that the randomness of the characters is strictly for testing purposes; also note that the disallowed characters are a small fraction of the total set of characters, and thus the adjustments rarely occur.