Display

Trait Display 

1.0.0 · Source
pub trait Display {
    // Required method
    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}
Format trait for an empty format, {}.

Implementing this trait for a type will automatically implement the ToString trait for the type, allowing the usage of the .to_string() method. Prefer implementing the Display trait for a type, rather than ToString.

Display is similar to Debug, but Display is for user-facing output, and so cannot be derived.

For more information on formatters, see the module-level documentation.

Completeness and parseability

Display for a type might not necessarily be a lossless or complete representation of the type. It may omit internal state, precision, or other information the type does not consider important for user-facing output, as determined by the type. As such, the output of Display might not be possible to parse, and even if it is, the result of parsing might not exactly match the original value.

However, if a type has a lossless Display implementation whose output is meant to be conveniently machine-parseable and not just meant for human consumption, then the type may wish to accept the same format in FromStr, and document that usage. Having both Display and FromStr implementations where the result of Display cannot be parsed with FromStr may surprise users.

Internationalization

Because a type can only have one Display implementation, it is often preferable to only implement Display when there is a single most “obvious” way that values can be formatted as text. This could mean formatting according to the “invariant” culture and “undefined” locale, or it could mean that the type display is designed for a specific culture/locale, such as developer logs.

If not all values have a justifiably canonical textual format or if you want to support alternative formats not covered by the standard set of possible formatting traits, the most flexible approach is display adapters: methods like str::escape_default or Path::display which create a wrapper implementing Display to output the specific display format.

Examples

Implementing Display on a type:

use std::fmt;

struct Point {
    x: i32,
    y: i32,
}

impl fmt::Display for Point {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "({}, {})", self.x, self.y)
    }
}

let origin = Point { x: 0, y: 0 };

assert_eq!(format!("The origin is: {origin}"), "The origin is: (0, 0)");

Required Methods

1.0.0 · Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Formats the value using the given formatter.

Errors

This function should return Err if, and only if, the provided Formatter returns Err. String formatting is considered an infallible operation; this function only returns a Result because writing to the underlying stream might fail and it must provide a way to propagate the fact that an error has occurred back up the stack.

Examples
use std::fmt;

struct Position {
    longitude: f32,
    latitude: f32,
}

impl fmt::Display for Position {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "({}, {})", self.longitude, self.latitude)
    }
}

assert_eq!(
    "(1.987, 2.983)",
    format!("{}", Position { longitude: 1.987, latitude: 2.983, }),
);

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Display for !

1.26.0 · Source

impl Display for AccessError

1.4.0 · Source

impl Display for AddrParseError

Source

impl Display for AllocError

1.0.0 · Source

impl Display for Arguments<'_>

Source

impl Display for AsciiChar

1.65.0 · Source

impl Display for Backtrace

Source

impl Display for BernoulliError

Source

impl Display for BigInt

Source

impl Display for BigInteger256

Source

impl Display for BigInteger384

Source

impl Display for BigUint

1.13.0 · Source

impl Display for BorrowError

1.13.0 · Source

impl Display for BorrowMutError

Source

impl Display for ByteStr

Source

impl Display for ByteString

Source

impl Display for CharError

1.34.0 · Source

impl Display for CharTryFromError

Source

impl Display for CheckedHrpstringError

Source

impl Display for ChecksumError

Source

impl Display for Class

Source

impl Display for CodeLengthError

Source

impl Display for CollectionAllocErr

Source

impl Display for ColoredString

Source

impl Display for ConstraintFieldError

Source

impl Display for DateTime

Source

impl Display for snarkvm_console_algorithms::bech32::segwit::DecodeError

Available on crate feature alloc only.
Source

impl Display for snarkvm_console_algorithms::bech32::DecodeError

Available on crate feature alloc only.
Source

impl Display for crypto_bigint::traits::DecodeError

1.9.0 · Source

impl Display for DecodeUtf16Error

Source

impl Display for DeserializeStateError

1.87.0 · Source

impl Display for std::ffi::os_str::Display<'_>

1.0.0 · Source

impl Display for std::path::Display<'_>

Source

impl Display for ECDSASignature

Source

impl Display for Empty

Source

impl Display for snarkvm_console_algorithms::bech32::segwit::EncodeError

Available on crate feature alloc only.
Source

impl Display for snarkvm_console_algorithms::bech32::EncodeError

Source

impl Display for EncodeIoError

Available on crate feature std only.
Source

impl Display for EncodingRules

1.0.0 · Source

impl Display for std::io::error::Error

1.0.0 · Source

impl Display for snarkvm_console_algorithms::fmt::Error

Source

impl Display for snarkvm_console_algorithms::Error

Source

impl Display for rand::distr::uniform::Error

Source

impl Display for rand::distr::weighted::Error

Source

impl Display for getrandom::error::Error

Source

impl Display for snarkvm_console_algorithms::de::value::Error

Source

impl Display for serde_json::error::Error

Source

impl Display for snarkvm_console_algorithms::bech32::primitives::hrp::Error

Source

impl Display for elliptic_curve::error::Error

Source

impl Display for base16ct::error::Error

Source

impl Display for sec1::error::Error

Source

impl Display for der::error::Error

Source

impl Display for const_oid::error::Error

Source

impl Display for block_buffer::Error

Source

impl Display for signature::error::Error

1.60.0 · Source

impl Display for core::io::error::ErrorKind

Source

impl Display for bincode::error::ErrorKind

Source

impl Display for der::error::ErrorKind

1.20.0 · Source

impl Display for core::char::EscapeDebug

1.39.0 · Source

impl Display for core::ascii::EscapeDefault

1.16.0 · Source

impl Display for core::char::EscapeDefault

1.16.0 · Source

impl Display for core::char::EscapeUnicode

1.0.0 · Source

impl Display for ExitStatus

Source

impl Display for ExitStatusError

Source

impl Display for Fe32

Source

impl Display for tracing_core::field::Field

Source

impl Display for FieldError

Source

impl Display for FieldSet

1.69.0 · Source

impl Display for FromBytesUntilNulError

1.17.0 · Source

impl Display for FromBytesWithNulError

Source

impl Display for FromCharError

Source

impl Display for FromHexError

1.0.0 · Source

impl Display for FromUtf8Error

1.0.0 · Source

impl Display for FromUtf16Error

1.58.0 · Source

impl Display for FromVecWithNulError

1.86.0 · Source

impl Display for core::slice::GetDisjointMutError

Source

impl Display for indexmap::GetDisjointMutError

Source

impl Display for GroupError

Source

impl Display for HexDisplay<'_>

Source

impl Display for Hrp

Displays the human-readable part.

If an uppercase HRP was parsed during object construction then the returned string will be in uppercase also. For a lowercase string see Self::to_lowercase.

1.34.0 · Source

impl Display for Infallible

1.7.0 · Source

impl Display for IntoStringError

Source

impl Display for InvalidBufferSize

Source

impl Display for InvalidKey

Source

impl Display for InvalidLength

Source

impl Display for InvalidOutputSize

Source

impl Display for InvalidWitnessVersionError

1.7.0 · Source

impl Display for IpAddr

1.0.0 · Source

impl Display for Ipv4Addr

1.0.0 · Source

impl Display for Ipv6Addr

Writes an Ipv6Addr, conforming to the canonical style described by RFC 5952.

1.0.0 · Source

impl Display for JoinPathsError

1.28.0 · Source

impl Display for LayoutError

Source

impl Display for Length

Source

impl Display for Level

Source

impl Display for LevelFilter

Source

impl Display for Limb

1.26.0 · Source

impl Display for Location<'_>

Source

impl Display for MacError

Source

impl Display for NormalizeError

1.0.0 · Source

impl Display for NulError

Source

impl Display for Number

Source

impl Display for ObjectIdentifierRef

Source

impl Display for PaddingError

1.26.0 · Source

impl Display for PanicHookInfo<'_>

1.26.0 · Source

impl Display for PanicInfo<'_>

1.81.0 · Source

impl Display for PanicMessage<'_>

Source

impl Display for ParseBigIntError

1.0.0 · Source

impl Display for ParseBoolError

1.20.0 · Source

impl Display for ParseCharError

1.0.0 · Source

impl Display for core::num::float_parse::ParseFloatError

Source

impl Display for num_traits::ParseFloatError

1.0.0 · Source

impl Display for ParseIntError

Source

impl Display for ParseLevelError

Source

impl Display for ParseLevelFilterError

1.0.0 · Source

impl Display for RecvError

1.15.0 · Source

impl Display for std::sync::mpsc::RecvTimeoutError

Source

impl Display for SegwitCodeLengthError

Source

impl Display for SegwitHrpstringError

Source

impl Display for SerializationError

Source

impl Display for SetGlobalDefaultError

Source

impl Display for SmolStr

1.0.0 · Source

impl Display for SocketAddr

1.0.0 · Source

impl Display for SocketAddrV4

1.0.0 · Source

impl Display for SocketAddrV6

1.0.0 · Source

impl Display for String

1.7.0 · Source

impl Display for StripPrefixError

1.8.0 · Source

impl Display for SystemTimeError

Source

impl Display for Tag

Source

impl Display for TagMode

Source

impl Display for TagNumber

Source

impl Display for ThreadPoolBuildError

1.16.0 · Source

impl Display for ToLowercase

Source

impl Display for ToTitlecase

1.16.0 · Source

impl Display for ToUppercase

1.59.0 · Source

impl Display for TryFromCharError

Source

impl Display for TryFromError

1.66.0 · Source

impl Display for TryFromFloatSecsError

1.34.0 · Source

impl Display for TryFromIntError

Source

impl Display for TryFromIteratorError

1.35.0 · Source

impl Display for core::array::TryFromSliceError

Source

impl Display for crypto_bigint::uint::encoding::TryFromSliceError

1.89.0 · Source

impl Display for std::fs::TryLockError

1.0.0 · Source

impl Display for std::sync::mpsc::TryRecvError

1.57.0 · Source

impl Display for alloc::collections::TryReserveError

Source

impl Display for indexmap::TryReserveError

Source

impl Display for hashbrown::TryReserveError

Source

impl Display for UintRef

Source

impl Display for UncheckedHrpstringError

Source

impl Display for UnorderedKeyError

1.0.0 · Source

impl Display for Utf8Error

Source

impl Display for Value

Source

impl Display for ValueSet<'_>

1.0.0 · Source

impl Display for VarError

Source

impl Display for WitnessLengthError

Source

impl Display for WouldBlock

1.56.0 · Source

impl Display for WriterPanicked

1.0.0 · Source

impl Display for bool

1.0.0 · Source

impl Display for char

Source

impl Display for dyn Expected + '_

Source

impl Display for dyn Value

1.0.0 · Source

impl Display for f16

1.0.0 · Source

impl Display for f32

1.0.0 · Source

impl Display for f64

1.0.0 · Source

impl Display for i8

1.0.0 · Source

impl Display for i16

1.0.0 · Source

impl Display for i32

1.0.0 · Source

impl Display for i64

1.0.0 · Source

impl Display for i128

1.0.0 · Source

impl Display for isize

1.0.0 · Source

impl Display for str

1.0.0 · Source

impl Display for u8

1.0.0 · Source

impl Display for u16

1.0.0 · Source

impl Display for u32

1.0.0 · Source

impl Display for u64

1.0.0 · Source

impl Display for u128

1.0.0 · Source

impl Display for usize

Source

impl<'a, I> Display for Format<'a, I>
where I: Iterator, <I as Iterator>::Item: Display,

1.60.0 · Source

impl<'a> Display for EscapeAscii<'a>

1.34.0 · Source

impl<'a> Display for snarkvm_console_algorithms::str::EscapeDebug<'a>

1.34.0 · Source

impl<'a> Display for snarkvm_console_algorithms::str::EscapeDefault<'a>

1.34.0 · Source

impl<'a> Display for snarkvm_console_algorithms::str::EscapeUnicode<'a>

Source

impl<'a> Display for Ia5StringRef<'a>

Source

impl<'a> Display for PrintableStringRef<'a>

Source

impl<'a> Display for TeletexStringRef<'a>

Source

impl<'a> Display for Unexpected<'a>

Source

impl<'a> Display for Utf8StringRef<'a>

Source

impl<'a> Display for VideotexStringRef<'a>

1.0.0 · Source

impl<B> Display for Cow<'_, B>
where B: Display + ToOwned + ?Sized, <B as ToOwned>::Owned: Display,

Source

impl<C> Display for NonZeroScalar<C>
where C: CurveArithmetic,

Source

impl<C> Display for ScalarValue<C>
where C: Curve,

Source

impl<C> Display for Signature<C>

Source

impl<E, I> Display for Integer<E, I>
where E: Environment, I: IntegerType,

Source

impl<E> Display for Boolean<E>
where E: Environment,

Source

impl<E> Display for Err<E>
where E: Debug,

Source

impl<E> Display for snarkvm_console_algorithms::Field<E>
where E: Environment,

Source

impl<E> Display for Group<E>
where E: Environment,

Source

impl<E> Display for Report<E>
where E: Error,

Source

impl<E> Display for Scalar<E>
where E: Environment,

1.93.0 · Source

impl<F> Display for FromFn<F>
where F: Fn(&mut Formatter<'_>) -> Result<(), Error>,

Source

impl<I, F> Display for FormatWith<'_, I, F>
where I: Iterator, F: FnMut(<I as Iterator>::Item, &mut dyn FnMut(&dyn Display) -> Result<(), Error>) -> Result<(), Error>,

Source

impl<I> Display for nom::error::Error<I>
where I: Display,

The Display implementation allows the std::error::Error implementation

Source

impl<I> Display for ExactlyOneError<I>
where I: Iterator,

Source

impl<I> Display for VerboseError<I>
where I: Display,

Available on crate feature alloc only.
Source

impl<K, V, S, A> Display for OccupiedError<'_, K, V, S, A>
where K: Debug, V: Debug, A: Allocator,

Source

impl<L, R> Display for Either<L, R>
where L: Display, R: Display,

Source

impl<P> Display for snarkvm_curves::templates::short_weierstrass_jacobian::affine::Affine<P>

Source

impl<P> Display for snarkvm_curves::templates::twisted_edwards_extended::affine::Affine<P>

Source

impl<P> Display for Fp2<P>
where P: Fp2Parameters,

Source

impl<P> Display for Fp6<P>
where P: Fp6Parameters,

Source

impl<P> Display for Fp12<P>
where P: Fp12Parameters,

Source

impl<P> Display for Fp256<P>
where P: Fp256Parameters,

Source

impl<P> Display for Fp384<P>
where P: Fp384Parameters,

Source

impl<P> Display for snarkvm_curves::templates::short_weierstrass_jacobian::projective::Projective<P>

Source

impl<P> Display for snarkvm_curves::templates::twisted_edwards_extended::projective::Projective<P>

1.33.0 · Source

impl<Ptr> Display for Pin<Ptr>
where Ptr: Display,

Source

impl<Size> Display for EncodedPoint<Size>
where Size: ModulusSize,

1.0.0 · Source

impl<T, A> Display for Arc<T, A>
where T: Display + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Display for Box<T, A>
where T: Display + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Display for Rc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, A> Display for UniqueArc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, A> Display for UniqueRc<T, A>
where T: Display + ?Sized, A: Allocator,

1.0.0 · Source

impl<T> Display for &T
where T: Display + ?Sized,

1.0.0 · Source

impl<T> Display for &mut T
where T: Display + ?Sized,

Source

impl<T> Display for CachePadded<T>
where T: Display,

Source

impl<T> Display for CapacityError<T>

Source

impl<T> Display for DisplayValue<T>
where T: Display,

Source

impl<T> Display for std::sync::nonpoison::mutex::MappedMutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::mutex::MappedMutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::MappedRwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::rwlock::MappedRwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::mutex::MutexGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::mutex::MutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for crypto_bigint::non_zero::NonZero<T>
where T: Display + ?Sized,

1.28.0 · Source

impl<T> Display for core::num::nonzero::NonZero<T>

Source

impl<T> Display for Odd<T>
where T: Display + ?Sized,

1.0.0 · Source

impl<T> Display for PoisonError<T>

Source

impl<T> Display for RandomBitsError<T>
where T: Display,

Available on crate feature rand_core only.
Source

impl<T> Display for std::sync::oneshot::RecvTimeoutError<T>

Source

impl<T> Display for ReentrantLockGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for Ref<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for RefMut<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::RwLockReadGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::rwlock::RwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::RwLockWriteGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::rwlock::RwLockWriteGuard<'_, T>
where T: Display + ?Sized,

1.74.0 · Source

impl<T> Display for Saturating<T>
where T: Display,

1.0.0 · Source

impl<T> Display for SendError<T>

Source

impl<T> Display for SendTimeoutError<T>

Source

impl<T> Display for ShardedLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for ShardedLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for ThinBox<T>
where T: Display + ?Sized,

Source

impl<T> Display for TryFromBigIntError<T>

1.0.0 · Source

impl<T> Display for std::sync::poison::TryLockError<T>

Source

impl<T> Display for std::sync::oneshot::TryRecvError<T>

1.0.0 · Source

impl<T> Display for TrySendError<T>

1.10.0 · Source

impl<T> Display for core::num::wrapping::Wrapping<T>
where T: Display,

Source

impl<T> Display for crypto_bigint::wrapping::Wrapping<T>
where T: Display,

1.0.0 · Source

impl<W> Display for IntoInnerError<W>

Source

impl<const CAP: usize> Display for ArrayString<CAP>

Source

impl<const LIMBS: usize> Display for Int<LIMBS>

Source

impl<const LIMBS: usize> Display for Uint<LIMBS>

Source

impl<const MAX_SIZE: usize> Display for ObjectIdentifier<MAX_SIZE>